package acg.prototype.content;

import java.util.Arrays;

import acg.prototype.db.DbAdapter;
import android.util.Log;

public class Checkbox extends Task {
	
	/**
	 * answers for this task
	 */
	private String[] answers;
	
	/**
	 * alternatives for this task
	 */
	private String[] alternatives;

	/**
	 * @param id
	 * 				- id of the task
	 * @param description
	 * 				- description of the task
	 * @param questions
	 * 				- the questions for the this task.
	 * @param penalty
	 * 				- penalty for asnwering this task wrong
	 * @param imageId
	 * 				- id of the image
	 * @param hints
	 * 				- hints for this task
	 * @param alternatives
	 * 				- alternatives for this task
	 * @param answers
	 * 				- answers for this task
	 * @param completed
	 * 				- whether or not the task is completed
	 * @param wrongAnswers
	 * 				- how many times the task has been answered wrong
	 * @param bypassCode
	 *            - the bypass/failsafe code that is required to auto-complete this task, reset it's hints used and wrong answers given
	 * @param da
	 * 				- DbAdapter for connecting to the database.
	 */
	public Checkbox(int id, String description, String[] questions, int penalty, int imageId, Hint[] hints, String[] alternatives, String[] answers, boolean completed, int wrongAnswers, String bypassCode, DbAdapter da) {
		super(id, Task.CHECKBOX_TASK, description, questions, penalty, imageId, hints, completed, wrongAnswers, bypassCode, da);
		this.alternatives = alternatives;
		this.answers = answers.clone();

	}

	/**
	 * Validates the given answer by the user against the real answer stored in the task. 
	 * @param givenAnswer - The answer given by the user
	 * @return true if correct, false otherwise
	 */
	public boolean validateTask(Object givenAnswer) {
		if (givenAnswer == null) {
			Log.e("debug cb", "given answer is null");
			return false;
		}
		String[] inc = (String[]) givenAnswer;
		if (inc.length!=answers.length) return false;
		Arrays.sort(inc);
		String[] answersclone = answers.clone();
		Arrays.sort(answersclone);
		return Arrays.equals(answersclone, inc);
	}
	
	/**
	 * Gets the alternatives for this task
	 * @return string array with alternatives
	 */
	public String[] getAlternatives() {
		return this.alternatives;
	}

}
