package acg.prototype.content;

import acg.prototype.db.DbAdapter;
import acg.prototype.util.GPSHandler;

public class GPS extends Task{
	
	/**
	 * GPSHandler for retrieving GPS coordinates.
	 */
	private GPSHandler gpsHandler;
	
	
	/**
	 * Constructs a new GPS task.
	 * 
	 * @param taskId - the database-id of the task.
	 * @param taskType - the task type of the task.
	 * @param description - the task description.
	 * @param penalty - the penalty for wrong answers.
	 * @param imageId - the database id for the image for this task.
	 * @param hints - the hints for this task.
	 * @param completed - denotes if the task is completed or not.
	 * @param wrongAnswers - the number of times the user has provided a wrong answer to the task.
	 * @param bypassCode - the bypass/failsafe code that is required to auto-complete this task, reset it's hints used and wrong answers given
	 * @param dbAdapter - DbAdapter for connecting to the database.
	 * @param gpsHandler - GPSHandler for retrieving GPS coordinates.
	 * @param latitude - the latitude of the location that the user should find.
	 * @param longitude - the longitude of the location that the user should find.
	 * @param radius - the radius around the fixed location. If the user is inside the radius, the task is complete.
	 */
	public GPS(int taskId, String description, int penalty, int imageId, Hint[] hints, boolean completed, int wrongAnswers, String bypassCode, DbAdapter dbAdapter, GPSHandler gpsHandler, double latitude, double longitude, float radius) {
		super(taskId, Task.GPS_TASK, description, new String[]{"Find the location"}, penalty, imageId, hints, completed, wrongAnswers, bypassCode, dbAdapter);
		this.gpsHandler = gpsHandler;
		gpsHandler.setCoordinates(latitude, longitude, radius);
	}
	
	/**
	 * Starts GPS updates.
	 */
	public void startGPS(){
		gpsHandler.startUpdates();
	}
	
	/**
	 * Stops GPS updates
	 */
	public void stopGPS(){
		gpsHandler.stopUpdates();
	}
	
	/**
	 * Returns true if the user is inside the range of the location, false otherwise.
	 * 
	 * @return true if the user is inside the range of the location, false otherwise.
	 */
	public boolean getInsideTaskRange(){
		return gpsHandler.getInsideTaskRange();
	}

	/**
	 * Returns true if GPSHandler.onLocationChanged method has been called, false otherwise.
	 * 
	 * @return true if GPSHandler.onLocationChanged method has been called, false otherwise.
	 */
	public boolean getOnLocationChanged(){
		return gpsHandler.getOnLocationChanged();
	}
	
	/**
	 * Sets GPSHandler.onLocationChanged.
	 * 
	 * @param onLocationChanged
	 */
	public void setOnLocationChanged(boolean onLocationChanged){
		gpsHandler.setOnLocationChanged(onLocationChanged);
	}
	
	
	@Override
	public boolean validateTask(Object givenAnswer) {
		// TODO Auto-generated method stub
		return false;
	}
}
