package acg.prototype.content;

import acg.prototype.db.DbAdapter;

public class MultipleChoice extends Task{

	/**
	 * The alternatives for this task.
	 */
	private String[] alternatives;
	
	/**
	 * The answer for this task (one of the alternatives).
	 */
	private String answer;

	/**
	 * Constructs a new MultipleChoice task.
	 * 
	 * @param id - the database-id of the task.
	 * @param taskType - the task type of the task.
	 * @param description - the task description. 
	 * @param questions - the questions for the this task.
	 * @param penalty - the penalty for wrong answers.	
	 * @param imageId - the database id for the image for this task. 
	 * @param hints - the hints for this task.
	 * @param alternatives - the alternatives for this task.
	 * @param answer - the answer for this task (one of the alternatives).
	 * @param completed - denotes if the task is completed or not.
	 * @param wrongAnswers - the number of times the user has provided a wrong answer to the task.
	 * @param bypassCode - the bypass/failsafe code that is required to auto-complete this task, reset it's hints used and wrong answers given
	 * @param da - DbAdapter for connecting to the database.
	 */
	public MultipleChoice(int id, String description, String[] questions, int penalty, int imageId, Hint[] hints, String[] alternatives, String answer, boolean completed, int wrongAnswers, String bypassCode, DbAdapter da){
		super(id, Task.MULTIPLE_CHOICE_TASK, description, questions, penalty, imageId, hints, completed, wrongAnswers, bypassCode, da);
		this.alternatives = alternatives;
		this.answer = answer;
	}

	/**
	 * Returns a String array containing the alternatives for this task.
	 * 
	 * @return a String array containing the alternatives for this task.
	 */
	public String[] getAlternatives() {
		return alternatives;
	}

	@Override
	/**
	 * Validates the given answer by the user against the real answer stored in the task. 
	 * @param givenAnswer - The answer given by the user
	 * @return true if correct, false otherwise
	 */
	public boolean validateTask(Object givenAnswer) {
		return answer.equals(givenAnswer.toString());
	}
}
