package acg.prototype.content;

import acg.prototype.db.DbAdapter;
import acg.prototype.util.Helper;

public class Open extends Task {
	
	/**
	 * The answer for this task.
	 */
	private String answer;
	
	/**
	 * Constructs a new Open task.
	 * 
	 * @param taskId - the database-id of the task.
	 * @param description - the task description. 
	 * @param questions - the questions for the this task.
	 * @param penalty - the penalty for wrong answers.	
	 * @param imageId - the database id for the image for this task. 
	 * @param hints - the hints for this task.
	 * @param answer - the answer for this task (one of the alternatives).
	 * @param completed - denotes if the task is completed or not.
	 * @param wrongAnswers - the number of times the user has provided a wrong answer to the task.
	 * @param bypassCode - the bypass/failsafe code that is required to auto-complete this task, reset it's hints used and wrong answers given
	 * @param da - DbAdapter for connecting to the database.
	 */
	public Open(int taskId, String description, String[] questions, int penalty, int imageId, Hint[] hints, String answer, boolean completed, int wrongAnswers, String bypassCode, DbAdapter da) {
		super(taskId, Task.OPEN_TASK, description, questions, penalty, imageId, hints, completed, wrongAnswers, bypassCode, da);
		this.answer = answer;
	}
	
	@Override
	/**
	 * Validates the given answer by the user against the real answer stored in the task. 
	 * @param givenAnswer - The answer given by the user
	 * @return true if correct, false otherwise
	 */
	public boolean validateTask(Object givenAnswer) {
		return Helper.standardize(answer).equals(Helper.standardize(givenAnswer.toString()));
	}
	
}
