package acg.prototype.content;

import acg.prototype.db.DbAdapter;

/**
 * The route of the game.
 */
public class Route {

	/**
	 * The database taskIds of all the task for this routes.
	 */
	private int[] taskIds;
	
	/**
	 * The database routeId of this route.
	 */
	private int routeId;

	
	/**
	 * Creates a new route. A random route is loaded from the database.
	 * 
	 * @param da - the dbAdapter for connecting to the database.
	 */
	public Route(DbAdapter da) {

		da.open();
		routeId = (int) (Math.random() * da.getNumberOfRoutes()) + 1;
		taskIds = da.getRoute(routeId);
		da.close();
		
	}
	
	/**
	 * Creates a new route according to the game state table in the database.
	 * 
	 * @param da - the dbAdapter for connecting to the database.
	 * @param routeId - the database routeId according to the current game state table.
	 */
	public Route(DbAdapter da, int routeId) {

		this.routeId = routeId;
		da.open();
		taskIds = da.getRoute(routeId);
		da.close();
	}
	
	
	/**
	 * Returns the routeId for this route.
	 * 
	 * @return The routeId for this route.
	 */
	public int getRouteId(){
		return routeId;
	}
	
	
	/**
	 * Returns the next taskId for this route
	 * 
	 * @param currentTaskId - the currentTaskId according to game state.
	 * @return The next taskId for this route.
	 */
	public int getNextTaskId(int currentTaskId){
		if(currentTaskId == 0) return taskIds[0];
		
		for (int i = 0; i < taskIds.length; i++) {
			if (taskIds[i] == currentTaskId && i+1 < taskIds.length) return taskIds[i+1];
		}
		
		return -1;
	}

	/**
	 * Returns the first task in the route.
	 * @return first task in the route
	 */
	public int getFirstTaskId() {
		return taskIds[0];
	}
	
}
