package acg.prototype.ui;

import acg.prototype.TaskActivity;
import acg.prototype.R;
import acg.prototype.content.Barcode;
import acg.prototype.content.Task;
import android.app.Activity;
import android.content.Intent;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.Toast;

/**
 * Implementation of TaskUI for the Barcode scanning task type.
 */
public class BarcodeScanningTaskUI extends TaskUI {

	/**
	 * Creates a new instance of the UI handler.
	 * 
	 * @param task
	 *            the task to be solved.
	 */
	public BarcodeScanningTaskUI(Task task, int[] taskIds, Activity activity) {
		super(task, taskIds, activity);
	}

	/**
	 * Creates and returns the UI of the task.
	 * 
	 * @return the UI of the task.
	 */
	public View createView() {

		// Creates a linear layout.
		createLayout();

		// Adds a text field with the task description.
		addDescription();

		// Adds the image if the task has a image.
		addImage();
		
		buildQuestions();

		Button scanButton = new Button(activity);
		scanButton.setText("SCAN");
		scanButton.setOnClickListener(new OnClickListener() {
			public void onClick(View v) {
				Intent intent = new Intent("com.google.zxing.client.android.SCAN");
				intent.setPackage("com.google.zxing.client.android");
				intent.putExtra("SCAN_MODE", "QR_CODE_MODE");
				activity.startActivityForResult(intent, TaskActivity.BARCODE_SCANNER_REQUEST_CODE);
			}
		});
		layout.addView(scanButton);

		// create hint interface and ok button
		createLowerInterface();
		// addHintView();
		// addOkButton();
		layout.addView(innerLowerLayout);

		// Returns the view.
		return scroll;
	}

	// /**
	// * Creates and returns the UI of the task.
	// *
	// * @return the UI of the task.
	// */
	// public View createView() {
	//
	// // Creates a linear layout.
	// LinearLayout layout = new LinearLayout(activity);
	// layout.setOrientation(LinearLayout.VERTICAL);
	//
	// // Adds a text field with the task description.
	// TextView description = new TextView(activity);
	// description.setText(task.getDescription());
	// layout.addView(description);
	//

	//
	// // Adds a scanning button.
	//
	//
	// // Adds a confirmation button.
	// Button okButton = new Button(activity);
	// okButton.setText("OK");
	// okButton.setOnClickListener(new OnClickListener() {
	// public void onClick(View v) {
	// // if (scannedText.equals(task.getAnswer())) {
	// // solveTask();
	// // }
	// }
	// });
	// layout.addView(okButton);
	//
	// // Returns the view.
	// return layout;
	// }

	@Override
	public Object getGivenAnswer() {
		// TODO Auto-generated method stub
		return null;
	}

	/**
	 * Provides the user with the route for the game determined by the scanned
	 * keyword.
	 * 
	 * @param keyword
	 *            the keyword the barcode the user scanned contained.
	 */
	public void provideRoute(String keyword) {
		Barcode b = (Barcode)task;
		boolean keywordIsCorrect = b.checkRouteKeyword(keyword);
		if ( keywordIsCorrect ) {
			Toast.makeText(activity, R.string.correctRoute, Toast.LENGTH_LONG).show();
			solveTask();
		} else {
			Toast.makeText(activity, R.string.wrongRoute, Toast.LENGTH_LONG).show();
		}
	}
}