package acg.prototype.ui;

import acg.prototype.content.Checkbox;
import acg.prototype.content.Task;
import android.app.Activity;
import android.view.View;
import android.widget.CheckBox;

/**
 * Implementation of TaskUI for the Checkbox task type.
 */
public class CheckBoxTaskUI extends TaskUI {
	
	/**
	 * the array containing the checkboxes representing alternatives
	 */
	private CheckBox[] checkboxArray;

	/**
	 * Creates a new instance of the UI handler.
	 * 
	 * @param task
	 *            the task to be solved.
	 */
	public CheckBoxTaskUI(Task task, int[] taskIds, Activity activity) {
		super(task, taskIds, activity);
	}

	/**
	 * Creates and returns the UI of the task.
	 * 
	 * @return the UI of the task.
	 */
	public View createView() {
		// Creates a linear layout.
		createLayout();

		// Adds a text field with the task description.
		addDescription();

		// Adds the image if the task has a image.
		addImage();
		
		buildQuestions();
		addHintView();
		createAlternatives();
		
		// create hint interface and ok button
		createLowerInterface();
		addHintButton();
		addOkButton();
		layout.addView(innerLowerLayout);

		// Returns the view.
		return scroll;
	}

	@Override
	/**
	 * Returns the answer given by the user.
	 * @return Object containing the answer given by the user of type String
	 */
	public Object getGivenAnswer() {
		String[] answers;
		int size = 0;
		for (int i=0; i<checkboxArray.length; i++) {
			if (checkboxArray[i].isChecked()) size++;
		}
		answers = new String[size];
		int position = 0;
		for (int i=0; i<checkboxArray.length; i++) {
			if (checkboxArray[i].isChecked()) {
					answers[position] = (String) checkboxArray[i].getText();
					position++;
			}
		}
		return answers;
	}
	
	/**
	 * Builds and adds alternatives to the task UI.
	 */
	private void createAlternatives() {
		String[] alternatives = ((Checkbox) task).getAlternatives();
		checkboxArray = new CheckBox[alternatives.length];
		for (int i=0; i<alternatives.length; i++) {
			CheckBox cb = new CheckBox(activity);
			cb.setText(alternatives[i]);
			layout.addView(cb);
			checkboxArray[i] = cb;
		}
	}

}
