package acg.prototype.ui;

import acg.prototype.R;
import acg.prototype.content.GPS;
import acg.prototype.content.Task;
import android.app.Activity;
import android.app.AlertDialog;
import android.app.ProgressDialog;
import android.content.DialogInterface;
import android.os.Handler;
import android.os.Message;
import android.os.SystemClock;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.LinearLayout.LayoutParams;
import android.widget.Toast;

/**
 * Implementation of TaskUI for the GPS task type. 
 */
public class GPSTaskUI  extends TaskUI {


	
	private Button gpsButton;
	
	/**
	 * The start time for the thread.
	 */
	private double startTime;
	
	
	/**
	 * Thread for checking GPS updates.
	 */
	private Thread t;
	
	private final ProgressDialog progressDialog;
	
	/**
	 * Message handler for retrieving messages from the GPS thread.
	 */
	private Handler messageHandler = new Handler() {		
	    @Override
	    public void handleMessage(Message msg) {  
	    	switch(msg.what){
	    	// If the user is not inside the radius.
	    	case 0:
	    		// Stops GPS updates.
	    		((GPS)task).stopGPS();
				
	    		// Enables the gpsButton.
	    		gpsButton.setEnabled(true);
				
	    		// Increases wrong answers.
	    		task.incWrongAnswers();
	    		
	    		progressDialog.dismiss();
	    		
        		Toast.makeText(activity, R.string.wrongLocation, Toast.LENGTH_LONG).show();
	  
        		break;
	    	// If the user is inside the radius.
	    	case 1:
	    		// Stops GPS updates.
	    		((GPS)task).stopGPS(); 
	    		
	    		progressDialog.dismiss();
	    		
	    		Toast.makeText(activity, R.string.correctLocation, Toast.LENGTH_LONG).show();
	    		
	    		// Solves the task.
	    		Button completeButton = new Button(activity);
	    		completeButton.setText(R.string.nextTask);
	    		completeButton.setLayoutParams(new LayoutParams(LayoutParams.FILL_PARENT, LayoutParams.WRAP_CONTENT, 1.0f));
	    		completeButton.setOnClickListener(new OnClickListener() {
	    			public void onClick(View v) {
	    				solveTask();
	    			}
	    		});
	    		layout.removeView(innerLowerLayout);
	    		layout.addView(completeButton);
	    		
	    		break;
	    	// If no GPS updates could be retrieved.
	    	case 2:
	    		// Stops GPS updates.
	    		((GPS)task).stopGPS();
	    		
	    		// Enables the gpsButton.
	    		gpsButton.setEnabled(true);
	    		
	    		progressDialog.dismiss();
	    		
	    		Toast.makeText(activity, R.string.unableToGPS, Toast.LENGTH_LONG).show();
	    		break;
	    	default:
	    		break;
	    	}
	    }
	};

	public GPSTaskUI(Task task, int[] taskIds, Activity activity) {
		super(task, taskIds, activity);
		startTime = 0;
		progressDialog = new ProgressDialog(activity);
	}
	@Override
	public View createView() {
		createLayout();
		
		addDescription();
		
		addImage();
		
		buildQuestions();
		
		progressDialog.setProgressStyle(ProgressDialog.STYLE_HORIZONTAL);
		progressDialog.setMessage(activity.getString(R.string.gpsProgressText));
		progressDialog.setMax(30);
		progressDialog.setCancelable(false);
		
		
		gpsButton = new Button(activity);
		gpsButton.setText(R.string.checkGPS);
		gpsButton.setLayoutParams(new LayoutParams(LayoutParams.FILL_PARENT, LayoutParams.WRAP_CONTENT, 1.0f));
		gpsButton.setOnClickListener(new OnClickListener() {
			public void onClick(View v) {
				//Ask the user to confirm answer
		        new AlertDialog.Builder(activity)
		        .setIcon(android.R.drawable.ic_dialog_alert)
		        .setTitle(R.string.confirmLocation)
		        .setMessage(activity.getString(R.string.confirmLocationText)+" "+task.getPenalty()+" minutes.")
		        .setPositiveButton(R.string.yes, new DialogInterface.OnClickListener() {

		            public void onClick(DialogInterface dialog, int which) {  
		            	// Sets the start time for the updates to system time.
						startTime = SystemClock.elapsedRealtime();
						
						// Disables the gpsButton.
						gpsButton.setEnabled(false);
						
						// Starts GPS updates.
						((GPS)task).startGPS();
						
						progressDialog.setProgress(0);
			            progressDialog.show();
						
						// Creates a new Thread.
						t = new Thread(){
							 public void run() {
					             boolean stop = false;
					             int oldProgress = 0;
					             while(!stop){    
									 while ((SystemClock.elapsedRealtime() - startTime) < 30000) {
										 int progress = (int)((SystemClock.elapsedRealtime() - startTime)/1000);
										 if(progress > oldProgress){
											 oldProgress = progress;
											 progressDialog.setProgress(progress);
										 }
										 // If the gpsHandler has received a new location.
										 if(((GPS)task).getOnLocationChanged()){
											 
											 ((GPS)task).setOnLocationChanged(false);
											 
											 // If the user is in range of the task.
											 // Sends a true-message to messageHandler.
											 // Stops the thread.
											 if(((GPS)task).getInsideTaskRange()){
												 messageHandler.sendMessage(Message.obtain(messageHandler, 1)); 
												 stop = true;
											 }else{
												 // If not in range of the task.
												 // Sends a false-message to messageHandler.
												 // Stops the thread.
												 messageHandler.sendMessage(Message.obtain(messageHandler, 0));
												 stop = true;
											 }
											 break;
										 }
									 }
									 // If no GPS coordinates could be retrieved.
									 // Sends a could not be retrieved message to messageHandler.
									 // Stops the thread.
									 if(!stop){
										 messageHandler.sendMessage(Message.obtain(messageHandler, 2));
										 stop = true;
									 }
			             		 }
					            
							 }
						};
						// Starts the thread if it is not running.
						if(!t.isAlive()) t.start();
		            }

		        })
		        .setNegativeButton(R.string.no, null)
		        .show();
				
				
			}
		});
		addHintView();
		createLowerInterface();
		addHintButton();
		innerLowerLayout.addView(gpsButton);
		layout.addView(innerLowerLayout);
		
		return scroll;
	}

	@Override
	public Object getGivenAnswer() {
		// TODO Auto-generated method stub
		return null;
	}
	
}
