package acg.prototype.ui;

import acg.prototype.content.MultipleChoice;
import acg.prototype.content.Task;
import android.app.Activity;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.RadioButton;
import android.widget.RadioGroup;

/**
 * Implementation of TaskUI for the Multiple Choice task type.
 */
public class MultipleChoiceTaskUI extends TaskUI {

	/**
	 * The active radio button.
	 */
	private RadioButton activeRadioButton;

	/**
	 * Creates a new instance of the UI handler.
	 * 
	 * @param task
	 *            the task to be solved.
	 */
	public MultipleChoiceTaskUI(Task task, int[] taskIds, Activity activity) {
		super(task, taskIds, activity);
	}

	/**
	 * Creates and returns the UI of the task.
	 * 
	 * @return the UI of the task.
	 */
	public View createView() {
		
		// Creates a linear layout.
		createLayout();

		// Adds a text field with the task description.
		addDescription();

		// Adds the image if the task has a image.
		addImage();
		
		buildQuestions();
		
		addHintView();
		
		createAlternatives();
		
		// create hint interface and ok button
		createLowerInterface();
		addHintButton();
		addOkButton();
		layout.addView(innerLowerLayout);

		// Returns the view.
		return scroll;
	}

	@Override
	/**
	 * Returns the answer given by the user.
	 * @return Object containing the answer given by the user of type String
	 */
	public Object getGivenAnswer() {
		return activeRadioButton.getText();
	}
	
	/**
	 * Adds a group of radio buttons with the alternatives to the task UI.
	 */
	private void createAlternatives() {
		RadioGroup rg = new RadioGroup(activity);
		for (int i = 0; i < ((MultipleChoice) task).getAlternatives().length; i++) {
			
			RadioButton radioButton = new RadioButton(activity);
			radioButton.setText(((MultipleChoice) task).getAlternatives()[i]);
			radioButton.setOnClickListener(new OnClickListener() {
				public void onClick(View v) {
					activeRadioButton = (RadioButton) v;
				}
			});
			rg.addView(radioButton);
			
			// Toggles the first button of the radiogroup by default.
			if(i == 0){
				activeRadioButton = radioButton;
				radioButton.toggle();
			}
		}
		layout.addView(rg);
	}
}