package acg.prototype.ui;

import acg.prototype.content.Task;
import android.app.Activity;
import android.view.View;
import android.widget.EditText;

/**
 * Implementation of TaskUI for the Open task type.
 */
public class OpenTaskUI extends TaskUI {
	
	/**
	 * The input field the user can type the answer into.
	 */
	private EditText inputText;

	/**
	 * Creates a new instance of the UI handler.
	 * 
	 * @param task
	 *            the task to be solved.
	 */
	public OpenTaskUI(Task task, int[] taskIds, Activity activity) {
		super(task, taskIds, activity);
	}

	/**
	 * Creates and returns the UI of the task.
	 * 
	 * @return the UI of the task.
	 */
	public View createView() {

		// Creates a linear layout.
		createLayout();
		
		// Adds a text field with the task description.
		addDescription();
		
		// Adds the image if the task has a image.
		addImage();
		
		buildQuestions();
		
		// Adds an editable text field
		inputText = new EditText(activity);
		inputText.setSingleLine();
		addHintView();
		layout.addView(inputText);
		
		// create hint interface and ok button
		createLowerInterface();
		addHintButton();
		addOkButton();
		layout.addView(innerLowerLayout);

		// Returns the view.
		return scroll;
	}

	@Override
	/**
	 * Returns the answer given by the user.
	 * @return Object containing the answer given by the user of type String
	 */
	public Object getGivenAnswer() {
		return inputText.getText();
	}
	
}