package acg.prototype.ui;

import acg.prototype.R;
import acg.prototype.content.Shazam;
import acg.prototype.content.Task;
import acg.prototype.util.Helper;
import android.app.Activity;
import android.media.MediaPlayer;
import android.view.Gravity;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.EditText;
import android.widget.LinearLayout.LayoutParams;

/**
 * Implementation of TaskUI for the Shazam task type.
 */
public class ShazamTaskUI extends TaskUI{

	/**
	 * The input field the user can type the answer into.
	 */
	private EditText inputText;

	/**
	 * Creates a new instance of the UI handler.
	 * 
	 * @param task - the task to be solved.
	 */
	public ShazamTaskUI(Task task, int[] taskIds, Activity activity) {
		super(task, taskIds, activity);
	}

	/**
	 * Creates and returns the UI of the task.
	 * 
	 * @return the UI of the task.
	 */
	public View createView() {

		// Creates a linear layout.
		createLayout();
		
		// Adds a text field with the task description.
		addDescription();
		
		// Adds the image if the task has a image.
		addImage();
		
		buildQuestions();
		
		layout.setGravity(Gravity.CENTER_HORIZONTAL);
		Button playButton = new Button(activity);
		playButton.setBackgroundDrawable(activity.getResources().getDrawable(R.drawable.playbutton));
		LayoutParams playButtonParams = new LayoutParams(LayoutParams.WRAP_CONTENT, LayoutParams.WRAP_CONTENT, 1.0f);
		playButtonParams.setMargins(1, 10, 1, 10);
		playButton.setLayoutParams(playButtonParams);
		playButton.setGravity(Gravity.CENTER_HORIZONTAL);
		final int songId = ((Shazam)task).getSongId();
		final MediaPlayer mp = MediaPlayer.create(activity, Helper.getSong(songId));
		playButton.setOnClickListener(new OnClickListener() {

			public void onClick(View v) {
			    if(mp.isPlaying()){
			    	mp.pause();
			    }else{
			    	mp.start();
			    }
			}
		});
		layout.addView(playButton);
		
		// Adds an editable text field
		inputText = new EditText(activity);
		inputText.setSingleLine();
		addHintView();
		layout.addView(inputText);
		
		// create hint interface and ok button
		createLowerInterface();
		addHintButton();
		addOkButton();
		layout.addView(innerLowerLayout);
		
		// Returns the view.
		return scroll;
	}

	@Override
	/**
	 * Returns the answer given by the user.
	 * @return Object containing the answer given by the user of type String
	 */
	public Object getGivenAnswer() {
		return inputText.getText();
	}

}
