package acg.prototype.util;

import acg.prototype.R;

/**
 * A class for keeping static helper methods
 */
public class Helper {

	/**
	 * A static method that returns the R-reference for an image.
	 * 
	 * @param imageId - the database image id.
	 * @return The R-reference to the right image.
	 */
	public static int getImage(int imageId){
		switch (imageId) {
		case 1:
			return R.drawable.oldbritannia;
		case 2:
			return R.drawable.flag;
		case 3:
			return R.drawable.oldnidaros;
		case 4:
			return R.drawable.ravnkloa;
		case 5:
			return R.drawable.bybro;
		case 6:
			return R.drawable.stiftsgarden;
		case 7:
			return R.drawable.torget;
		case 8:
			return R.drawable.vaarfruekirke;
		default:
			break;
		}
		return 0;
	}
	
	/**
	 * A static method that returns the R-reference for a song.
	 * 
	 * @param imageId - the database song id.
	 * @return The R-reference to the right song.
	 */
	public static int getSong(int songId){
		switch (songId) {
		case 1:
			return R.raw.irreplaceable;
		case 2:
			return R.raw.curious;
		case 3:
			return R.raw.sclub;
		default:
			break;
		}
		return 0;
	}
	
	/**
	 * Method used to standardize a text. Used when validating answers.
	 * Sets lower-case and strips the string for whitespaces and periods.
	 * @param text - The string to be standardized.
	 * @return A standardized string
	 */
	public static String standardize(String text){
		text = text.toLowerCase()
		.replace(" ", "")
		.replace(".", "");
		return text;
	}
}
